"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var yogaHandler_1 = require("../yogaHandler");
var rxjs_1 = require("rxjs");
var operators_1 = require("rxjs/operators");
var YogaContext = React.createContext({});
exports.YogaContextProvider = function (props) {
    var yogaContext = React.useContext(YogaContext);
    var yogaRef = props.yogaRef, otherProps = __rest(props, ["yogaRef"]);
    var _a = React.useState({}), yogaProps = _a[0], setYogaProps = _a[1];
    var $subjectRef = React.useRef(new rxjs_1.Subject());
    var $recalculateRef = React.useRef(new rxjs_1.Subject());
    React.useEffect(function () {
        setTimeout(function () {
            yogaContext.recalculate && yogaContext.recalculate.next();
        });
    }, [yogaProps.width, yogaProps.height]);
    React.useEffect(function () {
        var instance = yogaRef.current;
        if (!instance) {
            return;
        }
        var calculate = function () {
            yogaHandler_1.yogaHandler(instance, otherProps).then(function (newProps) {
                console.log('yoga mixin result', newProps);
                var yogaChildren = newProps.children, yogaPropsWithoutChildren = __rest(newProps, ["children"]);
                setYogaProps(yogaPropsWithoutChildren);
                instance.children.forEach(function (child, index) {
                    $subjectRef.current.next({ instance: child, props: yogaChildren[index] });
                });
            });
        };
        calculate();
        var recalculationPipe = $recalculateRef.current.pipe(operators_1.debounce(function () { return rxjs_1.interval(50); }));
        recalculationPipe.subscribe(calculate);
        return function () { return recalculationPipe.unsubscribe(); };
    }, []);
    return (React.createElement(YogaContext.Provider, { value: { subject: $subjectRef.current, recalculate: $recalculateRef.current } }, props.children({ yogaProps: yogaProps })));
};
exports.useYogaLayout = function (props) {
    var yogaRef = props.yogaRef;
    var _a = React.useState({}), yogaProps = _a[0], setYogaProps = _a[1];
    var context = React.useContext(YogaContext);
    React.useEffect(function () {
        var instance = yogaRef.current;
        if (!context.subject) {
            return;
        }
        var subject = context.subject.pipe(operators_1.filter(function (message) { return message.instance === instance; }), operators_1.map(function (message) { return message.props; }));
        subject.subscribe(setYogaProps);
        return function () { return subject.unsubscribe(); };
    }, []);
    React.useEffect(function () {
        var instance = yogaRef.current;
        if (!instance) {
            return;
        }
        if (instance.width !== yogaProps.width || instance.height !== yogaProps.height) {
            context.recalculate && context.recalculate.next();
        }
    }, [yogaProps.width, yogaProps.height]);
    return yogaProps;
};
//# sourceMappingURL=useYogaLayout.js.map