"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var transformFlexDirection = function (yoga) { return function (value) {
    switch (value) {
        case 'row':
            return yoga.FLEX_DIRECTION_ROW;
        case 'row-reverse':
            return yoga.FLEX_DIRECTION_ROW_REVERSE;
        case 'column-reverse':
            return yoga.FLEX_DIRECTION_COLUMN_REVERSE;
        default:
            return yoga.FLEX_DIRECTION_COLUMN;
    }
}; };
exports.yogaWorker = function (yoga) { return function (message) {
    if (!message.value || message.value.type !== 'calculateLayout') {
        return;
    }
    var props = message.value.value;
    var yogaRoot = yoga.Node.create();
    if (props.width) {
        yogaRoot.setWidth(props.width);
    }
    if (props.height) {
        yogaRoot.setHeight(props.height);
    }
    if (props.style) {
        var style = props.style;
        if (style.flexDirection) {
            yogaRoot.setFlexDirection(transformFlexDirection(yoga)(style.flexDirection));
        }
        if (style.paddingTop) {
            yogaRoot.setPadding(yoga.EDGE_TOP, style.paddingTop);
        }
        if (style.paddingBottom) {
            yogaRoot.setPadding(yoga.EDGE_BOTTOM, style.paddingBottom);
        }
        if (style.paddingLeft) {
            yogaRoot.setPadding(yoga.EDGE_LEFT, style.paddingLeft);
        }
        if (style.paddingRight) {
            yogaRoot.setPadding(yoga.EDGE_RIGHT, style.paddingRight);
        }
    }
    yogaRoot.setJustifyContent(yoga.JUSTIFY_CENTER);
    var recalculatedChildren = [];
    if (props.children) {
        var yogaNodes_1 = props.children.map(function (child, id) {
            var yogaNode = yoga.Node.create();
            if (child.width && child.height) {
                yogaNode.setWidth(child.width);
                yogaNode.setHeight(child.height);
            }
            if (child.style) {
                if (child.style.marginTop) {
                    yogaNode.setMargin(yoga.EDGE_TOP, child.style.marginTop);
                }
                if (child.style.marginBottom) {
                    yogaNode.setMargin(yoga.EDGE_BOTTOM, child.style.marginBottom);
                }
                if (child.style.marginLeft) {
                    yogaNode.setMargin(yoga.EDGE_LEFT, child.style.marginLeft);
                }
                if (child.style.marginRight) {
                    yogaNode.setMargin(yoga.EDGE_RIGHT, child.style.marginRight);
                }
            }
            yogaRoot.insertChild(yogaNode, id);
            return yogaNode;
        });
        yogaRoot.calculateLayout(props.width, props.height, yoga.DIRECTION_LTR);
        props.children.forEach(function (child, id) {
            var yogaNode = yogaNodes_1[id];
            var layoutProps = yogaNode.getComputedLayout();
            recalculatedChildren.push(layoutProps);
        });
    }
    var rootComputed = yogaRoot.getComputedLayout();
    parent.postMessage({
        pluginMessage: {
            id: message.id,
            value: {
                width: rootComputed.width,
                height: rootComputed.height,
                children: recalculatedChildren
            }
        }
    }, '*');
}; };
//# sourceMappingURL=yogaWorker.js.map